      subroutine hec_online_ana1
c
c pass 1 system histograms filling routine
c
      implicit none
c
      include'hec_par.inc'
c
c geometry correspondence tables common
c must be preceded by the include file hec_par.inc
c
      include'hec_geo.inc'
c
c online histogram id common
c
      include'hec_online_his.inc'
c
c pedestal values common
c must be preceded by the include file hec_par.inc
c
      include'hec_ped.inc'
c
c event header common (keeps event count i_event)
c
      include'hec_evth.inc'
c
c run header common
c
      include'hec_runh.inc'
c
c tdc common
c
      include'hec_tdc.inc'
c
c local variables
c
      integer ic, i_t, nid, nid2, id, ibin
      integer i_z, i_mod, i_eta, i_phi
      real sig_sum(i_z_max,i_mod_max)
      real avetdc(ntdc_bin), errtdc(ntdc_bin)
      real error(i_adc_dim)
      real weight, average
c
c if adcs are not read out for this run, do not try to fill histograms
c
      if (.not. calo_on_flag) then
        print *,' '
        print *,'WARNING!!!: ADCs not read out, skipping most'
     +         ,'            histograms (hec_online_ana1)'
        print *,' '
        return
      endif
c
c calculate pedestal mean and rms values
c
      call hec_ped_ana1
c
c fill adc pedestal and adc pedestal rms histograms
c
      nid = 0
      nid2 = 0
      call vzero(sig_sum,i_z_max*i_mod_max)
c
      do ic = 1, i_adc_used
        call hf1(id_ped, adc_ped_run(ic), 1.)
        call hf1(id_ped_ic, real(ic), adc_ped_run(ic))
        call hf1(id_rms, adc_rms_run(ic), 1.)
c
c fill error array for rms vs. ic plot
c use counter from maximum moments to get total
c number of events.
c
        if (maxmom(ic,1) .ge. 1) then
          error(ic) = adc_rms_run(ic)/sqrt(2.*real(maxmom(ic,1)))
        endif
c
c fill arrays for histo of max vs. channel
c
        if (adc_rms_run(ic) .lt. 25. .and. maxmom(ic,1) .ge. 1.) then
          average_max(ic) = maxmom(ic,2) / maxmom(ic,1)
          errmax(ic) = (sqrt(maxmom(ic,3)/maxmom(ic,1) - 
     +                  (average_max(ic)**2))/sqrt(maxmom(ic,1)))
        else
          print *,'ic of bad cell is ',ic
          average_max(ic) = 0.
          errmax(ic) = 0.
        endif
c
c fill histo with lego map of weighted "hits" in each layer
c
        i_eta = ictoph(ic,1)
        i_phi = ictoph(ic,2)
        i_z = ictoph(ic,3)
        if (maxmom(ic,1) .ge. 1) then
          weight = maxmom(ic,2) / maxmom(ic,1)
        else
          weight = 0.
        endif
        if (i_eta .le. 6. .and. i_z .eq. 1) then
          id = id_map
          call hfill(id,real(i_phi),real(i_eta),weight)
        elseif (i_eta .le. 6. .and. i_z .eq. 2) then
          id = id_map + 1
          call hfill(id,real(i_phi),real(i_eta),weight)
        elseif (i_eta .le. 6. .and. i_z .eq. 3) then
          id = id_map + 2
          call hfill(id,real(i_phi),real(i_eta),weight)
        endif
c
c sum to get average content of each depth for each module
c (includes bad cell cut)
c
        i_z = ictoph(ic,3)
        i_mod = ictodb(ic,1)
        if (i_z .ne. 0 .and. i_mod .ne. 0) then
          sig_sum(i_z,i_mod) = sig_sum(i_z,i_mod) + 
     +                       average_max(ic)
        endif
c
c fill time profile histograms
c
        do i_t = 1, i_tim_used
c
          if (adcmom(ic,i_t,1) .ge. 1) then
            average = adcmom(ic,i_t,2) / adcmom(ic,i_t,1)
          else
            average = 0.
          endif
c
          id = id_tprof_ic + ic
          call hff1(id, nid, real(i_t), average)
        enddo
c
c fill time profile which includes tdc value
c
c errtdc is actually rms/rootn (error on the mean)
c
        do ibin = 1, ntdc_bin
          if (tdcmom(ic,ibin,1) .ne. 0.) then
            avetdc(ibin) = tdcmom(ic,ibin,2)/tdcmom(ic,ibin,1)
            errtdc(ibin) = (sqrt(tdcmom(ic,ibin,3)/tdcmom(ic,ibin,1) 
     +                  - (avetdc(ibin))**2))/sqrt(tdcmom(ic,ibin,1))
          else
            avetdc(ibin) = 0.
            errtdc(ibin) = 0.
          endif
        enddo
        id = id_timns_ic + ic
        call hpak(id,avetdc)    
        call hpake(id,errtdc)
c
      enddo
c
c fill histogram of rms vs. channel number
c error is (bin content)/sqrt(2n)
c
      call hpak(id_rms_ic,adc_rms_run)    
      call hpake(id_rms_ic,error)
c
c fill histogram of maximum adc vs. channel number
c
      call hpak(id_max_ic,average_max)    
      call hpake(id_max_ic,errmax)
c
c fill depth profile histos
c
      do i_mod = 1, i_mod_used
        do i_z = 1, i_z_used
          id = id_adc_z + i_z_used + i_mod
          call hfill(id,i_z-0.5,0.,sig_sum(i_z,i_mod))
        enddo
      enddo
c
c output run sheet for triggers
c
      call hec_trig_sheet
c 
      end



