      logical function hec_s_found()
************************************************************************
*     general signal searching function                                *
*                                                                      *
*     input: none                                                      *
*                                                                      *
*     hec_s_found    .TRUE.   event shape in this adc channel  	       *
*     hec_s_found    .FALSE.  no event in this adc channel             *
*     hec_s_found    .FALSE.  any kind of error                        *
*                                                                      *
*     if irunpd < 4  (no FADC yet available):                          *
*                       hec_s_found = .TRUE. and return                *
*                                                                      *
* ->  required:                                                        *
*     EVERY search algorythm HAS to fill two things:                   *
*     1st: hec_s_result(,) at the end this array is in such a way that *
*                       the 3rd array element (=3rd timeslice) is the  *
*                       maximum. The reason is to fit later really the *
*                       same things!                                   *
*     2nd: hec_s_im     index (# of timeslice) of the recognised       *
*                       maximum                                        *
*                                                                      *
*     kind 0:           -> logical function hec_s_0                    *
*     =======                                                          *
*     function does no selection. It take every event and returns in   *
*     the searching arrays the unchanged adc values for all            *
*     timeslices.                                                      *
*     Use this routine to disable the searching algorythms !           *
*                                                                      *
*     kind 1:           -> logical function hec_s_1                    *
*     =======                                                          *
*     function first searches absolut (pure) maximum in the range      *
*     hec_s_start...hec_s_stop . If this signal is above               *
*     hec_s_lvllevel*sigma, then the time distribution is compared     *
*     with the puls shape in s simple way.                             *
*     The posibility to compare 3, 5 and 7 timeslices is provided.     *
*     function searches only amoung physics trigger                    *
*                                                                      *
*     kind 2:           -> logical function hec_s_2                    *
*     =======                                                          *
*     empty dummy routine. This could be replaced by a special user    *
*     implementation of his own algorythm                              *
*                                                                      *
*     kind 3..infty:    -> logical function hec_s_#                    *
*     ==============                                                   *
*     not yet implemented                                              *
*                                                                      *
*     author: 27.05.1997   Dieter Striegel   (kind=1)                  *
*             01.11.1997   Dieter Striegel   (kind=0+2)                *
************************************************************************
      implicit none

      include 'hec_par.inc' 				! parameter common
      include 'hec_geo.inc' 				! geometry common
      include 'hec_datacard.inc' 			! datacard common
      include 'hec_search.inc' 				! search common
      include 'hec_trig.inc' 				! trigger common

      character substr*18 				! subroutine string
      logical DEBUG
      parameter (substr=' *** HEC_S_FOUND: ', DEBUG=.FALSE.)
      
      logical hec_s_0, hec_s_1, hec_s_2, hec_s_work
      external hec_s_0, hec_s_1, hec_s_2

      if (irunpd.lt.4) then 				! no FADC available
        hec_s_found=.TRUE.
        return
      endif 						! if (irunpd.lt.4) then

      hec_s_work=.FALSE. 				! assume no signal

      if (DEBUG) write(*,*) substr,'requested search algo: ',hec_s_k

      if (hec_s_k .eq. 0) then
      
        hec_s_work = hec_s_0() 				! take everything
        
      elseif (hec_s_k.eq.1) then
      
        if (trig_physics) then 				! select only physics triggers
          hec_s_work = hec_s_1()			! use algorythm 1
        else
          hec_s_work = .FALSE.
        endif 						! if(trig_physics) then

      elseif (hec_s_k.eq.2) then
      
        hec_s_work = hec_s_2() 				! use algorythm 2
        
      else

        write(*,'(2A,I3,A)') substr,'search algorythm # ',hec_s_k,
     &                              ' not yet implemented.'
        write(*,*) substr,'returning with .FALSE. !!!'
        hec_s_work=.FALSE.

      endif 						! if (hec_s_k.eq.0) then

      if (DEBUG) write(*,*) substr,'signal found = ', hec_s_work
      
      hec_s_found=hec_s_work
      
      return
      end
